@@ -36,7 +36,10 @@ class Follow(models.Model):
     actor = generic.GenericForeignKey()
     
     objects = FollowManager()
-    
+
+    class Meta:
+        unique_together = ("user", "content_type", "object_id")
+
     def __unicode__(self):
         return u'%s -> %s' % (self.user, self.actor)
 
@@ -157,11 +160,12 @@ def follow(user, actor, send_action=True):
         follow(request.user, group)
     
     """
+    follow,created = Follow.objects.get_or_create(user=user, object_id=actor.pk, 
+        content_type=ContentType.objects.get_for_model(actor))
     if send_action:
         action.send(user, verb=_('started following'), target=actor)
-    return Follow.objects.create(user = user, object_id = actor.pk, 
-        content_type = ContentType.objects.get_for_model(actor))
-    
+    return follow
+
 def unfollow(user, actor, send_action=False):
     """
     Removes ``User`` -> ``Actor`` follow relationship. 
